@@ -88,7 +88,7 @@ msgstr "bar"
         Test that weird occurrences are correctly parsed.
         """
         po = polib.pofile('tests/test_weird_occurrences.po')
-        self.assertEqual(len(po), 46)
+        self.assertEqual(len(po), 47)
 
     def test_pofile_and_mofile9(self):
         """
@@ -209,7 +209,7 @@ msgstr ""
     
     def test_detect_encoding1(self):
         """
-        Test that given enconding is returned when file has no encoding defined.
+        Test that given encoding is returned when file has no encoding defined.
         """
         self.assertEqual(polib.detect_encoding('tests/test_noencoding.po'), 'utf-8')
 
@@ -314,6 +314,10 @@ msgstr ""
         po = polib.pofile('tests/test_utf8.po')
         self.assertEqual(po[-1].linenum, 3478)
 
+    def test_windows_path_occurrences(self):
+        po = polib.pofile('tests/test_weird_occurrences.po')
+        self.assertEqual(po[0].occurrences, [('C:\\foo\\bar.py', '12')])
+
 
 class TestBaseFile(unittest.TestCase):
     """
@@ -414,7 +418,10 @@ class TestBaseFile(unittest.TestCase):
             ('Language-Team', u('LANGUAGE <LL@li.org>')),
             ('MIME-Version', u('1.0')),
             ('Content-Type', u('text/plain; charset=UTF-8')),
-            ('Content-Transfer-Encoding', u('8bit'))
+            ('Content-Transfer-Encoding', u('8bit')),
+            ('X-Poedit-SearchPath-1', u('Foo')),
+            ('X-Poedit-SearchPath-2', u('Bar')),
+            ('X-Poedit-SearchPath-10', u('Baz')),
         ]
         self.assertEqual(pofile.ordered_metadata(), mdata)
 
